@@ -24,18 +24,17 @@
 #include "utils.h"
 #include "loader_interface.h"
 
-extern const unsigned long init_array_start[];
-extern const unsigned long init_array_end[];
+extern const unsigned long wdfuncs_start[];
+extern const unsigned long wdfuncs_end[];
 extern CHAR16 *boot_medium_path;
 
 #define PCI_GET_VENDOR_ID(id)	(UINT16)(id)
 #define PCI_GET_PRODUCT_ID(id)	(UINT16)((id) >> 16)
 
-typedef EFI_STATUS (*WATCHDOG_PROBE)(EFI_PCI_IO *, UINT16, UINT16, UINTN);
 
 static EFI_STATUS probe_watchdogs(UINTN timeout)
 {
-	if (init_array_end - init_array_start == 0) {
+	if (wdfuncs_end - wdfuncs_start - 1 == 0) {
 		if (timeout > 0) {
 			ERROR(L"No watchdog drivers registered, but timeout is non-zero.\n");
 			return EFI_UNSUPPORTED;
@@ -84,8 +83,8 @@ static EFI_STATUS probe_watchdogs(UINTN timeout)
 			continue;
 		}
 
-		for (const unsigned long *entry = init_array_start;
-		     entry < init_array_end; entry++) {
+		const unsigned long *entry = wdfuncs_start;
+		for (entry++; entry < wdfuncs_end; entry++) {
 			WATCHDOG_PROBE probe = (WATCHDOG_PROBE) *entry;
 			if ((status = probe(pci_io, PCI_GET_VENDOR_ID(value),
 					    PCI_GET_PRODUCT_ID(value),
@@ -122,8 +121,10 @@ EFI_STATUS efi_main(EFI_HANDLE image_handle, EFI_SYSTEM_TABLE *system_table)
 	this_image = image_handle;
 	InitializeLib(this_image, system_table);
 
+#if !defined(SILENT_BOOT)
 	(VOID) ST->ConOut->ClearScreen(ST->ConOut);
 	PrintC(EFI_CYAN, L"EFI Boot Guard %s\n", L"" EFIBOOTGUARD_VERSION);
+#endif
 
 	status = BS->OpenProtocol(this_image, &LoadedImageProtocol,
 				  (VOID **)&loaded_image, this_image, NULL,
@@ -214,5 +215,7 @@ EFI_STATUS efi_main(EFI_HANDLE image_handle, EFI_SYSTEM_TABLE *system_table)
 	INFO(L"Starting %s with watchdog set to %d seconds ...\n",
 	     bg_loader_params.payload_path, bg_loader_params.timeout);
 
+	BS->Stall(1000 * 1000 * ENV_BOOT_DELAY);
+
 	return BS->StartImage(payload_handle, NULL, NULL);
 }
